package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.PosFeedbackMapper;
import com.ruoyi.system.domain.PosFeedback;
import com.ruoyi.system.service.IPosFeedbackService;

/**
 * PosFeedbackService业务层处理
 * 
 * @author ruoyi
 * @date 2024-07-24
 */
@Service
public class PosFeedbackServiceImpl extends ServiceImpl<BaseMapper<PosFeedback>,PosFeedback> implements IPosFeedbackService
{
    @Autowired
    private PosFeedbackMapper posFeedbackMapper;

    /**
     * 查询PosFeedback
     * 
     * @param id PosFeedback主键
     * @return PosFeedback
     */
    @Override
    public PosFeedback selectPosFeedbackById(Long id)
    {
        return posFeedbackMapper.selectPosFeedbackById(id);
    }

    /**
     * 查询PosFeedback列表
     * 
     * @param posFeedback PosFeedback
     * @return PosFeedback
     */
    @Override
    public List<PosFeedback> selectPosFeedbackList(PosFeedback posFeedback)
    {
        return posFeedbackMapper.selectPosFeedbackList(posFeedback);
    }

    /**
     * 新增PosFeedback
     * 
     * @param posFeedback PosFeedback
     * @return 结果
     */
    @Override
    public int insertPosFeedback(PosFeedback posFeedback)
    {
        return posFeedbackMapper.insertPosFeedback(posFeedback);
    }

    /**
     * 修改PosFeedback
     * 
     * @param posFeedback PosFeedback
     * @return 结果
     */
    @Override
    public int updatePosFeedback(PosFeedback posFeedback)
    {
        return posFeedbackMapper.updatePosFeedback(posFeedback);
    }

    /**
     * 批量删除PosFeedback
     * 
     * @param ids 需要删除的PosFeedback主键
     * @return 结果
     */
    @Override
    public int deletePosFeedbackByIds(Long[] ids)
    {
        return posFeedbackMapper.deletePosFeedbackByIds(ids);
    }

    /**
     * 删除PosFeedback信息
     * 
     * @param id PosFeedback主键
     * @return 结果
     */
    @Override
    public int deletePosFeedbackById(Long id)
    {
        return posFeedbackMapper.deletePosFeedbackById(id);
    }
}
